@@ -5,7 +5,7 @@
 #include <math.h>
 #include "hap.h"
 
-int n_subjects, n_loci=0, n_phase, *alleles, all_snps=0;
+static int n_subjects, n_loci=0, n_phase, *alleles, all_snps=0;
 long n_warn = 0;
 double **af,**pq;
 FILE *outfile;
